ContinuousScheduleViewController class Controllers and callbacks
- Inheritance
-
- Object
- ViewController
- ScheduleViewController
- ContinuousScheduleViewController
Constructors
-
ContinuousScheduleViewController({Location? location, required ScheduleViewConfiguration viewConfiguration, required ValueNotifier<
FloatingDateTimeRange?> floatingVisibleRange, required ValueNotifier<Set< visibleEvents, required FloatingDateTime initialDate})KalenderEvent> >
Properties
- cache → EventLayoutDelegateCache
-
The cache used by the event layout delegate.
finalinherited
- currentPage ↔ int
-
The index of the current page.
getter/setter pairinherited
-
floatingVisibleRange
→ ValueNotifier<
FloatingDateTimeRange?> -
The range currently visible.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInitialized → bool
-
Check if the controller has been initialized with the necessary components.
no setterinherited
-
highlightedRange
→ ValueNotifier<
FloatingDateTimeRange?> -
The highlighted date time range.
finalinherited
- initialDate → FloatingDateTime
-
The initial date to display in the schedule view.
finalinherited
- itemCount → int
-
Get the number of items for the current page.
no setterinherited
- itemPositionsListener ↔ ItemPositionsListener?
-
The
ItemPositionsListenerused to listen to the scroll position of the list.getter/setter pairinherited - itemScrollController ↔ ItemScrollController?
-
The
ItemScrollControllerused to control the scrollable list of the current page.getter/setter pairinherited - location ↔ Location?
-
getter/setter pairinherited
- multiDayCache → MultiDayLayoutFrameCache
-
The cache used for the multi-day event layout.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewConfiguration → ScheduleViewConfiguration
-
The view configuration that will be used by the controller.
finalinherited
-
visibleEvents
↔ ValueNotifier<
Set< KalenderEvent> > -
The KalenderEvents that are currently visible.
latefinalinherited
Methods
-
addItem(
{required ListItem item, required FloatingDateTime date, bool isFirst = false}) → void -
Add an item to the schedule map of the current page.
inherited
-
addItemForPage(
{required ListItem item, required FloatingDateTime date, required int pageIndex, bool isFirst = false}) → void -
Add an item to the map.
inherited
-
animateToDate(
DateTime date, {Duration? duration, Curve? curve}) → Future< void> -
Animate to the date part of the given DateTime.
override
-
animateToDateTime(
DateTime date, {Duration? pageDuration, Curve? pageCurve, Duration? scrollDuration, Curve? scrollCurve}) → Future< void> -
Animate to the date and time parts of the given DateTime.
override
-
animateToEvent(
KalenderEvent event, {Duration? pageDuration, Curve? pageCurve, Duration? scrollDuration, Curve? scrollCurve, bool centerEvent = true}) → Future< void> -
Animate to the given KalenderEvent.
override
-
animateToNextPage(
{Duration? duration, Curve? curve}) → Future< void> -
Animate to the next page.
override
-
animateToPreviousPage(
{Duration? duration, Curve? curve}) → Future< void> -
Animate to the previous page.
override
-
clear(
) → void -
Clear the schedule map for the current page.
inherited
-
clearPage(
int pageIndex) → void -
inherited
-
closestIndex(
DateTime date) → int -
Get the index closest to the given DateTime of the current page.
inherited
-
closestIndexForPage(
int pageIndex, DateTime date) → int -
Find the index of the row whose date is closest to
date.inherited -
closestMonthIndex(
int pageIndex, FloatingDateTime date) → int -
Get the month index for the given pageIndex and date.
inherited
-
dateTimeFromIndex(
int index) → FloatingDateTime? -
Get the DateTime for the given index of the current page.
inherited
-
dateTimeFromIndexForPage(
int pageIndex, int itemIndex) → FloatingDateTime? -
Get the FloatingDateTime for the given pageIndex and itemIndex.
inherited
-
dateTimeItemIndex(
int pageIndex) → DateTimeItemIndex -
Get the
DateTimeItemIndexfor the given pageIndex.inherited -
dispose(
) → void -
inherited
-
indexFromDateTime(
DateTime date) → int? -
Get the index of the item for the given DateTime for the current page.
inherited
-
indexFromDateTimeForPage(
int pageIndex, DateTime date) → int? -
inherited
-
indexItem(
int pageIndex) → IndexItem -
Get the
IndexItemfor the given pageIndex.inherited -
initialScrollIndex(
DateTime date) → int -
Find the initial scroll index for the given date.
inherited
-
item(
int index) → ListItem? -
Get the item at the given index of the current page.
inherited
-
itemCountForPage(
int pageIndex) → int -
Get the number of items for the given pageIndex.
inherited
-
itemIndexDateTime(
int pageIndex) → IndexItemDateTime -
Get the
IndexItemDateTimefor the given pageIndex.inherited -
jumpToDate(
DateTime date) → void -
Jump to the given DateTime.
override
-
jumpToPage(
int page) → void -
Jump to the given DateTime.
override
-
monthIndexFromDateTime(
int pageIndex, FloatingDateTime date) → int? -
Get the month index for the given pageIndex and date.
inherited
-
monthIndices(
int pageIndex) → DateTimeItemIndex -
Get the
DateTimeItemIndexfor the given pageIndex.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
populateMaps(
int numberOfPages) → void -
Populate the maps with the given number of pages.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited