DayDetail class Controllers and callbacks

The detail for when the calendar is tapped.

Inheritance

Constructors

DayDetail({required DateTime date, required RenderBox renderBox, required Offset localOffset})
Creates a new DayDetail with the given date.
const

Properties

date → DateTime
The date that was tapped.
final
hashCode → int
The hash code for this object.
no setterinherited
isDayDetail → bool
Returns true if the detail is a DayDetail.
no setterinherited
isMultiDayDetail → bool
Returns true if the detail is a MultiDayDetail.
no setterinherited
localOffset → Offset
The local offset of the tap.
finalinherited
renderBox → RenderBox
The render box of the gesture detector that was tapped.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited