DefaultEventsController class
The default EventsController for managing CalendarEvents.
- Inheritance
-
- Object
- EventsController
- DefaultEventsController
Constructors
-
DefaultEventsController({List<
Location> ? locations}) - Creates a DefaultEventsController.
Properties
-
events
→ Iterable<
CalendarEvent> -
The list of
CalendarEvents.no setteroverride - eventStore → DefaultEventStore
-
latefinal
-
feedbackWidgetSize
→ ValueNotifier<
Size> -
A ValueNotifier that holds the size of the feedback widget.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
locations
→ List<
Location> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEvent(
CalendarEvent event) → String -
Adds an CalendarEvent to the EventsController.
override
-
addEvents(
List< CalendarEvent> events) → List<String> -
Adds a list of CalendarEvents to the EventsController.
override
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
byId(
String id) → CalendarEvent? -
Retrieve a CalendarEvent by it's id if it exists.
override
-
clearEvents(
) → void -
Removes all CalendarEvents from
_events.override -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
eventsFromDateTimeRange(
InternalDateTimeRange dateTimeRange, {bool includeMultiDayEvents = true, bool includeDayEvents = true, Location? location}) → Iterable< CalendarEvent> -
Finds the CalendarEvents that occur during the
dateTimeRange.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeById(
String id) → void -
Remove an CalendarEvent with its id.
override
-
removeEvent(
CalendarEvent event) → void -
Removes an CalendarEvent from the list of CalendarEvents.
override
-
removeEvents(
List< CalendarEvent> events) → void -
Remove a list of CalendarEvent from the controller.
override
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeWhere(
bool test(String key, CalendarEvent element)) → void -
Removes a list of CalendarEvents from the list of CalendarEvents.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateEvent(
{required CalendarEvent event, required CalendarEvent updatedEvent}) → void -
Updates an CalendarEvent.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited