DurationMultiDayLayoutStrategy class Layout
Places the longest events first, breaking ties by start time.
- Inheritance
-
- Object
- MultiDayLayoutStrategy
- DurationMultiDayLayoutStrategy
Constructors
- DurationMultiDayLayoutStrategy()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateFrame(
{required FloatingDateTimeRange visibleRange, required List< KalenderEvent> events, required TextDirection textDirection, required Location? location, required MultiDayLayoutFrameCache? cache}) → MultiDayLayoutFrame -
The layout frame for
eventsacrossvisibleRange.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override