EventLayoutData class Layout

This stores the final layout data of a single KalenderEvent.

Constructors

EventLayoutData({required double left, required double right, required VerticalLayoutData verticalLayoutData})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
The id of the event.
no setter
left → double
The left of the event.
final
The right of the event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalLayoutData → VerticalLayoutData
The vertical layout data of the event.
final
width → double
The width of the event.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overlaps(VerticalLayoutData other) → bool
Checks if this EventLayoutData overlaps with other.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited