HorizontalConfiguration class abstract Views

The base class for all horizontal views of the calendar.

Implementers

Constructors

HorizontalConfiguration({bool showTiles = kDefaultShowEventTiles, double tileHeight = kDefaultTileHeight, MultiDayLayoutStrategy multiDayLayoutStrategy = kDefaultMultiDayLayoutStrategy, int? maximumNumberOfVerticalEvents, EdgeInsets eventPadding = kDefaultMultiDayEventPadding, required bool allowSingleDayEvents, PageTriggerConfiguration pageTriggerConfiguration = const PageTriggerConfiguration.defaultConfiguration()})
const

Properties

allowSingleDayEvents → bool
Whether to display single-day events in this horizontal lane.
final
eventPadding → EdgeInsets
The padding used around events.
final
hashCode → int
The hash code for this object.
no setteroverride
maximumNumberOfVerticalEvents → int?
The maximum number of events that can be displayed vertically.
final
multiDayLayoutStrategy → MultiDayLayoutStrategy
The strategy that assigns each multi-day event a row and a span of columns.
final
pageTriggerConfiguration → PageTriggerConfiguration
The configuration for the page navigation triggers.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showTiles → bool
Whether to show event tiles.
final
tileHeight → double
The height of the tiles.
final

Methods

copyWith({double? tileHeight, bool? showTiles, MultiDayLayoutStrategy? multiDayLayoutStrategy, int? maximumNumberOfVerticalEvents, EdgeInsets? eventPadding, bool? allowSingleDayEvents, PageTriggerConfiguration? pageTriggerConfiguration}) → HorizontalConfiguration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override