maximumNumberOfVerticalEvents property

int? maximumNumberOfVerticalEvents
final

The maximum number of events that can be displayed vertically.

If this is null, then there is no limit.

Implementation

final int? maximumNumberOfVerticalEvents;