HourLinesStyle class

The style of the HourLines widget.

Constructors

HourLinesStyle({Color? color, double? thickness, double? indent, double? endIndent})
const

Properties

color Color?
The Color of the hour lines.
final
endIndent double?
The end indent of the hour lines.
final
hashCode int
The hash code for this object.
no setterinherited
indent double?
The indent of the hour lines.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double?
The thickness of the hour lines.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited