InputMode enum Interaction

The InputMode defines the type of input the calendar should optimize for.

This affects how resize handles are positioned and how visibility is triggered.

Inheritance
Available extensions

Values

auto → const InputMode

Automatically detect input type.

Uses the platform heuristic as a fallback (iOS/Android → imprecise, otherwise → precise). At runtime, hover events indicate precise input and selection indicates imprecise input.

precise → const InputMode

Precise input mode (mouse, stylus, trackpad).

Resize handles span the full width/height of the event tile and are shown on hover.

imprecise → const InputMode

Imprecise input mode (touch/finger).

Resize handles are positioned at corners for easier targeting and are shown when the event is selected.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InputMode>
A constant List of the values in this enum, in order of their declaration.