location property

Location? get location

The location of the calendar. Null uses the device's local time.

Setting a different location recreates the view controller in it. With a null location, so does a change of the device timezone found when the app resumes.

Implementation

Location? get location => _location;
set location (Location? value)

Implementation

set location(Location? value) {
  if (value == _location) return;
  final previous = _location;
  _location = value;
  try {
    _switchTo(_viewConfiguration, locationChanged: true);
  } catch (_) {
    _location = previous;
    rethrow;
  }
}