KalenderInteraction class Interaction

The KalenderInteraction class defines the interaction settings for the calendar.

This class allows you to configure various aspects of how users can interact with the calendar, such as resizing, rescheduling, and creating events. It also provides settings for snapping events to specific intervals or other events.

Example usage:

KalenderInteraction(
  allowResizing: true,
  allowRescheduling: true,
  allowEventCreation: true,
);

Constructors

KalenderInteraction({bool allowResizing = defaultAllowResizing, bool allowRescheduling = defaultAllowRescheduling, bool allowEventCreation = defaultAllowEventCreation, InputMode inputMode = defaultInputMode, bool allowHorizontalImpreciseResize = defaultAllowHorizontalImpreciseResize, EventInteractionGesture? createEventGesture, EventInteractionGesture? modifyEventGesture})
Creates a new KalenderInteraction instance with the specified settings.

Properties

allowEventCreation bool
Allow the creation of events.
final
allowHorizontalImpreciseResize bool
Whether to allow horizontal resize handles in InputMode.imprecise mode.
final
allowRescheduling bool
Allow the rescheduling of events.
final
allowResizing bool
Allow the resizing of events.
final
createEventGesture EventInteractionGesture
The gesture used to create an event.
final
hashCode int
The hash code for this object.
no setteroverride
inputMode InputMode
The input mode for the calendar.
final
modifyEventGesture EventInteractionGesture
The gesture used to modify an event.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowResizing, bool? allowRescheduling, bool? allowEventCreation, InputMode? inputMode, bool? allowHorizontalImpreciseResize, EventInteractionGesture? createEventGesture, EventInteractionGesture? modifyEventGesture}) KalenderInteraction
Creates a copy of this KalenderInteraction but with the given fields replaced with the new values. If the fields are not provided, the original values will be used.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveIsImprecise() bool
Resolves whether the current input mode is imprecise.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override