allowResizing property
Allow the resizing of events.
If set to true, users can resize events by dragging their edges.
Implementation
final bool allowResizing;
Allow the resizing of events.
If set to true, users can resize events by dragging their edges.
final bool allowResizing;