copyWith method

KalenderInteraction copyWith({
  1. bool? allowResizing,
  2. bool? allowRescheduling,
  3. bool? allowEventCreation,
  4. InputMode? inputMode,
  5. bool? allowHorizontalImpreciseResize,
  6. EventInteractionGesture? createEventGesture,
  7. EventInteractionGesture? modifyEventGesture,
})

Creates a copy of this KalenderInteraction but with the given fields replaced with the new values. If the fields are not provided, the original values will be used.

Implementation

KalenderInteraction copyWith({
  bool? allowResizing,
  bool? allowRescheduling,
  bool? allowEventCreation,
  InputMode? inputMode,
  bool? allowHorizontalImpreciseResize,
  EventInteractionGesture? createEventGesture,
  EventInteractionGesture? modifyEventGesture,
}) {
  return KalenderInteraction(
    allowResizing: allowResizing ?? this.allowResizing,
    allowRescheduling: allowRescheduling ?? this.allowRescheduling,
    allowEventCreation: allowEventCreation ?? this.allowEventCreation,
    inputMode: inputMode ?? this.inputMode,
    allowHorizontalImpreciseResize: allowHorizontalImpreciseResize ?? this.allowHorizontalImpreciseResize,
    createEventGesture: createEventGesture ?? this.createEventGesture,
    modifyEventGesture: modifyEventGesture ?? this.modifyEventGesture,
  );
}