KalenderSnapping class Interaction

How a dragged or resized event snaps to time intervals, the time indicator and other events.

Constructors

KalenderSnapping({int snapIntervalMinutes = defaultSnapIntervalMinutes, bool snapToTimeIndicator = defaultSnapToTimeIndicator, bool snapToOtherEvents = defaultSnapToOtherEvents, Duration snapRange = defaultSnapRange, EventSnapStrategy eventSnapStrategy = kDefaultSnapStrategy})
const

Properties

eventSnapStrategy → EventSnapStrategy
The strategy used to snap events to specific intervals.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapIntervalMinutes → int
The snap interval in minutes for events.
final
snapRange → Duration
The Duration in which events will snap to other events.
final
snapToOtherEvents → bool
Whether to snap to other events when altering an event.
final
snapToTimeIndicator → bool
Whether to snap to the time indicator when altering an event.
final

Methods

copyWith({int? snapIntervalMinutes, bool? snapToTimeIndicator, bool? snapToOtherEvents, Duration? snapRange, EventSnapStrategy? eventSnapStrategy}) → KalenderSnapping
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override