KalenderView class Views

A calendar that shows the events of eventsController in the view kalenderController holds.

Inheritance

Constructors

KalenderView({Key? key, required EventsController eventsController, required KalenderController kalenderController, List<ViewParts<ViewConfiguration>> views = defaultViews, KalenderCallbacks? callbacks, KalenderInteraction? interaction, KalenderComponents? components, Locale? locale})
const

Properties

callbacks → KalenderCallbacks?
The callbacks of every view. A header or body given its own callbacks uses those instead.
final
components → KalenderComponents?
The components and styles used by the calendar.
final
eventsController → EventsController
The EventsController that will be used to populate the events in the calendar view.
final
hashCode → int
The hash code for this object.
no setterinherited
interaction → KalenderInteraction?
The interaction of every view. A header or body given its own interaction uses that instead.
final
kalenderController → KalenderController
The KalenderController that holds the view configuration and location.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
The locale used for internationalization, for example const Locale('en', 'US').
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
views → List<ViewParts<ViewConfiguration>>
The header and body shown for each kind of view configuration. See ViewParts.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<KalenderView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultViews → const List<ViewParts<ViewConfiguration>>
The built-in parts of every view.