MonthBodyComponents class

The component builders used by the MonthBody.

  • Using these will override the respective default components.

Constructors

MonthBodyComponents({MonthGridBuilder monthGridBuilder = MonthGrid.builder, MonthDayHeaderBuilder monthDayHeaderBuilder = MonthDayHeader.builder, HorizontalTriggerWidgetBuilder? leftTriggerBuilder, HorizontalTriggerWidgetBuilder? rightTriggerBuilder, OverlayBuilders? overlayBuilders = const OverlayBuilders()})
Creates overrides for the default components used by the MonthBody.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
leftTriggerBuilder HorizontalTriggerWidgetBuilder?
A function that builds the left trigger widget.
final
monthDayHeaderBuilder MonthDayHeaderBuilder
A function that builds the month day header widget.
final
monthGridBuilder MonthGridBuilder
A function that builds the month grid widget.
final
overlayBuilders OverlayBuilders?
A group of builders for the overlay widgets.
final
rightTriggerBuilder HorizontalTriggerWidgetBuilder?
A function that builds the right trigger widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited