MonthViewController class Controllers and callbacks

The controller of a month view. It opens on the month of the date of initial.

Inheritance

Constructors

MonthViewController({required MonthViewConfiguration viewConfiguration, required ViewSnapshot initial, Location? location})

Properties

cache → EventLayoutDelegateCache
The cache used by the event layout delegate.
finalinherited
floatingVisibleRange → ValueNotifier<FloatingDateTimeRange>
The range currently visible.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initialPage ↔ int
The initial page of the view.
latefinal
location → Location?
The location of the current view.
finalinherited
multiDayCache → MultiDayLayoutFrameCache
The cache used for the multi-day event layout.
finalinherited
numberOfPages ↔ int
The number of pages in the view.
latefinal
pageController ↔ PageController
The page controller used by the view.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewConfiguration → MonthViewConfiguration
The view configuration that will be used by the controller.
final
visibleEvents → ValueNotifier<Set<KalenderEvent>>
The KalenderEvents that are currently visible.
finalinherited

Methods

animateToDate(DateTime date, {Duration? duration, Curve? curve}) → Future<void>
Animate to the date part of the given DateTime.
animateToDateTime(DateTime date, {Duration? pageDuration, Curve? pageCurve, Duration? scrollDuration, Curve? scrollCurve}) → Future<void>
Animate to the date and time parts of the given DateTime.
animateToEvent(KalenderEvent event, {Duration? pageDuration, Curve? pageCurve, Duration? scrollDuration, Curve? scrollCurve, bool centerEvent = true}) → Future<void>
Animate to the given KalenderEvent.
animateToNextPage({Duration? duration, Curve? curve}) → Future<void>
Animate to the next page.
animateToPreviousPage({Duration? duration, Curve? curve}) → Future<void>
Animate to the previous page.
dispose() → void
override
jumpToDate(DateTime date) → void
Jump to the given DateTime.
override
jumpToPage(int page) → void
Jump to the given page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshot() → ViewSnapshot
Returns the first day of the month with the most visible days.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited