MonthViewParts class Views

The parts of a MonthViewConfiguration: a MonthHeader and a MonthBody by default.

Inheritance

Constructors

MonthViewParts({String? name, Widget? header, Widget? body})
const

Properties

body → Widget?
The widget below the header. Null shows builtInBody.
finalinherited
builtInBody → Widget?
The body shown when body is null. Null shows none.
no setteroverride
builtInHeader → Widget?
The header shown when header is null. Null shows none.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
The widget above the body. Null shows builtInHeader, and SizedBox.shrink shows nothing.
finalinherited
name → String?
The ViewConfiguration.name these parts show, or null for any configuration of type C.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accepts(ViewConfiguration configuration) → bool
Whether these parts show configuration.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited