MultiDayBodyComponentStyles class

The styles of the default components used by the MultiDayBody.

Constructors

MultiDayBodyComponentStyles({DaySeparatorStyle daySeparatorStyle = const DaySeparatorStyle(), TimeIndicatorStyle timeIndicatorStyle = const TimeIndicatorStyle(), HourLinesStyle hourLinesStyle = const HourLinesStyle(), TimelineStyle timelineStyle = const TimelineStyle()})
Creates a override for the default styles used by the MultiDayBody.
const

Properties

daySeparatorStyle DaySeparatorStyle
The styles of the day separator.
final
hashCode int
The hash code for this object.
no setterinherited
hourLinesStyle HourLinesStyle
The styles of the hour lines.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeIndicatorStyle TimeIndicatorStyle
The styles of the time indicator.
final
timelineStyle TimelineStyle
The styles of the timeline.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited