MultiDayBodyComponents class Appearance

The component builders used by the MultiDayBody.

Constructors

MultiDayBodyComponents({HourLinesBuilder? hourLines, TimeLineBuilder? timeline, KalenderTimeStringBuilder? timelineStringBuilder, TimelineWidthBuilder? timelineWidth, DaySeparatorBuilder? daySeparator, TimeIndicatorBuilder? timeIndicator, HorizontalTriggerWidgetBuilder? leftTriggerBuilder, HorizontalTriggerWidgetBuilder? rightTriggerBuilder, VerticalTriggerWidgetBuilder? topTriggerBuilder, VerticalTriggerWidgetBuilder? bottomTriggerBuilder})
const

Properties

bottomTriggerBuilder → HorizontalTriggerWidgetBuilder?
A function that builds the bottom trigger widget.
final
daySeparator → DaySeparatorBuilder?
A function that builds the day separator widget. Null uses DaySeparator.
final
hashCode → int
The hash code for this object.
no setteroverride
hourLines → HourLinesBuilder?
A function that builds the hour lines widget. Null uses HourLines.
final
leftTriggerBuilder → HorizontalTriggerWidgetBuilder?
A function that builds the left trigger widget.
final
rightTriggerBuilder → HorizontalTriggerWidgetBuilder?
A function that builds the right trigger widget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeIndicator → TimeIndicatorBuilder?
A function that builds the time indicator widget. Null uses TimeIndicator.
final
timeline → TimeLineBuilder?
A function that builds the timeline widget.
final
timelineStringBuilder → KalenderTimeStringBuilder?
Builds the labels displayed by the timeline.
final
timelineWidth → TimelineWidthBuilder?
Resolves the width of the timeline gutter.
final
topTriggerBuilder → HorizontalTriggerWidgetBuilder?
A function that builds the top trigger widget.
final

Methods

buildDaySeparator(BuildContext context) → Widget
Builds a day separator, with daySeparator when set.
buildHourLines(BuildContext context, double heightPerMinute, KalenderTimeRange timeOfDayRange) → Widget
Builds the hour lines, with hourLines when set.
buildTimeIndicator(BuildContext context, KalenderTimeRange timeOfDayRange, double heightPerMinute, Location? location, {NowCallback? nowCallback}) → Widget
Builds the time indicator, with timeIndicator when set.
buildTimeline(BuildContext context, double heightPerMinute, KalenderTimeRange timeOfDayRange, ValueNotifier<KalenderEvent?> eventBeingDragged, ValueListenable<KalenderDateTimeRange> visibleDateTimeRange) → Widget
Builds the timeline, with timeline when set.
buildTimelineWidth(BuildContext context, KalenderTimeRange timeOfDayRange) → double
Resolves the gutter width, with timelineWidth when set.
copyWith({HourLinesBuilder? hourLines, TimeLineBuilder? timeline, KalenderTimeStringBuilder? timelineStringBuilder, TimelineWidthBuilder? timelineWidth, DaySeparatorBuilder? daySeparator, TimeIndicatorBuilder? timeIndicator, HorizontalTriggerWidgetBuilder? leftTriggerBuilder, HorizontalTriggerWidgetBuilder? rightTriggerBuilder, VerticalTriggerWidgetBuilder? topTriggerBuilder, VerticalTriggerWidgetBuilder? bottomTriggerBuilder}) → MultiDayBodyComponents
Creates a copy of this with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override