MultiDayEventTileUtils mixin Appearance

Utilities for a tile that represents an event spanning several days, in the month view or the multi-day header.

Mixed in the same way as DayEventTileUtils.

Implemented types

Properties

event → KalenderEvent
The KalenderEvent that the tile is representing.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileRange → KalenderDateTimeRange
The KalenderDateTimeRange that the tile is being displayed within.
no setteroverride

Methods

dateFromPosition(BuildContext context, Offset localPosition) → DateTime
The start of the day at localPosition, an offset from the top-left corner of the tile.
floatingTileRange(BuildContext context) → FloatingDateTimeRange
Converts tileRange into an FloatingDateTimeRange using the current LocationProvider.
override
nearbyEvents(BuildContext context, {Duration before = Duration.zero, Duration after = Duration.zero, bool includeMultiDayEvents = true, bool includeDayEvents = true, bool includeSelf = false}) → List<KalenderEvent>
The events that overlap the event's range widened by before at the start and after at the end.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited