MultiDayHeader class Views

The multi-day header decides which header to display the:

  • _SingleDayHeader this is used for a body that only displays a single day.
  • _MultiDayHeader this is used for a body that displays multiple days.
  • _FreeScrollHeader this is used for a body that scrolls freely.

The single-day and multi-day headers use an ExpandablePageView to size the header to the current page. The free-scroll header instead renders one continuous band (see _FreeScrollMultiDayBand) so multi-day events can span day columns.

Inheritance

Constructors

MultiDayHeader({Key? key, HorizontalConfiguration? configuration})
Creates a new MultiDayHeader.
const

Properties

configuration HorizontalConfiguration?
The MultiDayHeaderConfiguration that will be used by the MultiDayHeader.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited