MultiDayLayoutFrame class

Frame containing all the data to layout the CalendarEvents with MultiDayLayout.

Annotations

Constructors

MultiDayLayoutFrame({required InternalDateTimeRange dateTimeRange, required List<EventLayoutInformation> layoutInfo, required List<CalendarEvent> events, required int totalNumberOfRows, required Map<int, int> columnRowMap})
const

Properties

columnRowMap Map<int, int>
A map that contains the number of rows for each date.
final
dateTimeRange InternalDateTimeRange
The range of dates that this frame is for.
final
events List<CalendarEvent>
The sorted events for this frame that will be used to generate MultiDayEventTiles.
final
hashCode int
The hash code for this object.
no setterinherited
layoutInfo List<EventLayoutInformation>
The layout information for each event in this frame.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalNumberOfRows int
The number of rows needed to layout all the events.
final

Methods

dateFromColumn(int column) InternalDateTime
Returns the date for the given column index.
eventsForColumn(int column) List<CalendarEvent>
Returns the events that should be displayed in the given column.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visibleEvents(int? maxNumberOfRows) → (List<CalendarEvent>, List<EventLayoutInformation>)
Returns the visible events and their layout information based on the provided max number of rows.

Operators

operator ==(Object other) bool
The equality operator.
inherited