MultiDayOverlay class Appearance

Inheritance

Constructors

MultiDayOverlay({Key? key, required FloatingDateTime date, required List<KalenderEvent> events, required double tileHeight, required OverlayPortalController portalController, required MultiDayOverlayEventTileBuilder overlayTileBuilder, required RenderBoxCallback getMultiDayEventLayoutRenderBox, required RenderBoxCallback getOverlayPortalRenderBox, MultiDayOverlayStyle? style})
const

Properties

date → FloatingDateTime
The date for which the widget is created.
final
events → List<KalenderEvent>
All the events that should be displayed for the given date.
final
getMultiDayEventLayoutRenderBox → RenderBoxCallback
The function that returns the RenderBox of the multi-day events widget.
final
getOverlayPortalRenderBox → RenderBoxCallback
The function that returns the RenderBox for the overlay portal.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
overlayTileBuilder → MultiDayOverlayEventTileBuilder
The builder for the overlay event tile.
final
portalController → OverlayPortalController
The portal controller that controls the overlay for this widget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → MultiDayOverlayStyle?
The style for the overlay.
final
tileHeight → double
The height of the tile.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBarrierKey(DateTime date) → Key
Returns a Key for the barrier behind the card, based on the date.
getCloseButtonKey(DateTime date) → Key
Returns a Key for the close button based on the date.
getHeaderKey(DateTime date) → Key
Returns a Key for the card's header, based on the date.
getKey(DateTime date) → Key
Returns a Key for the overlay based on the date.
getOverlayCardKey(DateTime date) → Key
Returns a Key for the overlay card based on the date.

Constants

defaultHeaderHeight → const double
defaultWidth → const double
todayKey → const ValueKey<String>
Key applied to the IconButton when the date is today.