MultiDayPortalOverlayButtonBuilder typedef Appearance

MultiDayPortalOverlayButtonBuilder = Widget Function(BuildContext context, OverlayPortalController portalController, int numberOfHiddenRows)

The builder used to create the button for the MultiDayPortalOverlayButton.

portalController is the controller for the overlay portal. numberOfHiddenRows is the number of events that are not displayed because of constraints.

Resolve the style with KalenderTheme.

Implementation

typedef MultiDayPortalOverlayButtonBuilder =
    Widget Function(BuildContext context, OverlayPortalController portalController, int numberOfHiddenRows);