OverlapLayoutStrategy class Layout

Lays out the tiles on top of each other.

Inheritance

Constructors

OverlapLayoutStrategy()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDelegate({required Iterable<KalenderEvent> events, required FloatingDateTime date, required KalenderTimeRange timeOfDayRange, required double heightPerMinute, required double? minimumTileHeight, required EventLayoutDelegateCache? cache, required Location? location}) EventLayoutDelegate
The delegate that lays out events in the column for date.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override