ResizeDirection enum

The ResizeDirection is used to differentiate between the different directions that an event can be resized in.

Inheritance
Available extensions

Values

left → const ResizeDirection

Resizes the event to the left.

Resizes the event to the right.

top → const ResizeDirection

Resizes the event to the top.

bottom → const ResizeDirection

Resizes the event to the bottom.

Properties

hashCode int
The hash code for this object.
no setterinherited
horizontal bool
Is the ResizeDirection in a horizontal direction. left/right
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertical bool
Is the ResizeDirection in a vertical direction. top/bottom
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ResizeDirection>
A constant List of the values in this enum, in order of their declaration.