ResizeHandleStyle class Appearance

The style of the resize handles laid out by DefaultResizeHandles.

The handle widgets themselves come from TileComponents.verticalResizeHandle and TileComponents.horizontalResizeHandle. This sizes the area each one is given.

Mixed-in types

Constructors

ResizeHandleStyle({double? length, double? impreciseLength})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
impreciseLength → double?
The length of a resize handle for imprecise input, such as a finger.
final
length → double?
The length of a resize handle for precise input, such as a mouse.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? length, double? impreciseLength}) → ResizeHandleStyle
Creates a copy of this style with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ResizeHandleStyle? other) → ResizeHandleStyle
Returns a copy of this style where the non-null fields of other replace the matching fields.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(ResizeHandleStyle? a, ResizeHandleStyle? b, double t) → ResizeHandleStyle?
Linearly interpolates between a and b.