ScheduleBodyConfiguration class Views

Constructors

ScheduleBodyConfiguration({EmptyDayBehavior emptyDay = kDefaultEmptyDayBehavior, double leadingWidth = kDefaultScheduleLeadingWidth, PageTriggerConfiguration? pageTriggerConfiguration, ScrollTriggerConfiguration? scrollTriggerConfiguration, ScrollPhysics? scrollPhysics, ScrollPhysics? pageScrollPhysics})

Properties

emptyDay → EmptyDayBehavior
The behavior of empty days in the schedule view.
final
hashCode → int
The hash code for this object.
no setteroverride
leadingWidth → double
The width of the leading (date) column, the same for every row. Defaults to kDefaultScheduleLeadingWidth.
final
pageScrollPhysics → ScrollPhysics?
The ScrollPhysics used by the page view.
final
pageTriggerConfiguration → PageTriggerConfiguration
The configuration for the page navigation triggers.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollPhysics → ScrollPhysics?
The ScrollPhysics used by the scrollable body.
final
scrollTriggerConfiguration → ScrollTriggerConfiguration
The configuration for the scroll navigation triggers.
final

Methods

copyWith({EmptyDayBehavior? emptyDay, double? leadingWidth, PageTriggerConfiguration? pageTriggerConfiguration, ScrollTriggerConfiguration? scrollTriggerConfiguration, ScrollPhysics? scrollPhysics, ScrollPhysics? pageScrollPhysics}) → ScheduleBodyConfiguration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override