ScrollTriggerConfiguration class

The configuration for the scroll triggers.

The scroll triggers are used to scroll the view when the user is dragging an event.

Constructors

ScrollTriggerConfiguration({Duration triggerDelay = const Duration(milliseconds: 750), Duration animationDuration = const Duration(milliseconds: 200), Curve animationCurve = Curves.easeInOut, double triggerHeight(double pageHeight)?, double scrollAmount(double pageHeight)?})
ScrollTriggerConfiguration.defaultConfiguration()
const

Properties

animationCurve Curve
The curve of the scroll animation.
final
animationDuration Duration
The duration of the scroll animation.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollAmount double Function(double pageHeight)?
The delta used to scroll the view.
final
triggerDelay Duration
The delay before the scroll trigger is activated.
final
triggerHeight double Function(double pageHeight)?
Calculation used to determine the height of the trigger.
final

Methods

copyWith({Duration? triggerDelay, Duration? animationDuration, Curve? animationCurve, double triggerHeight(double pageHeight)?}) ScrollTriggerConfiguration
Creates a copy of this ScrollTriggerConfiguration but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override