SideBySideLayoutDelegate class Layout
The SideBySideLayoutDelegate lays out KalenderEvents next to one another.
- Inheritance
-
- Object
- MultiChildLayoutDelegate
- EventLayoutDelegate
- SideBySideLayoutDelegate
Constructors
-
SideBySideLayoutDelegate({required Iterable<
KalenderEvent> events, required double heightPerMinute, required FloatingDateTime date, required Location? location, required KalenderTimeRange timeOfDayRange, required double? minimumTileHeight, required EventLayoutDelegateCache layoutCache})
Properties
- date → FloatingDateTime
-
The date for which the events are laid out.
finalinherited
-
events
→ Iterable<
KalenderEvent> -
The list of events that will be laid out. (The order of these events are the same as the widget's)
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightPerMinute → double
-
The height per minute of the current view.
finalinherited
- layoutCache → EventLayoutDelegateCache
-
The cache for the EventLayoutDelegate.
finalinherited
- location → Location?
-
The location for which the events are laid out.
finalinherited
- minimumTileHeight → double?
-
The minimum height of a tile.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeOfDayRange → KalenderTimeRange
-
The time of day range for which the events are laid out.
finalinherited
Methods
-
calculateVerticalLayoutData(
Size size) → List< VerticalLayoutData> -
Vertical layout of the events.
inherited
-
findLongestChain(
Iterable< VerticalLayoutData> verticalLayoutData) → int -
The length of the longest chain of overlapping entries in
verticalLayoutData.inherited -
getSize(
BoxConstraints constraints) → Size -
Override this method to return the size of this object given the
incoming constraints.
inherited
-
groupVerticalLayoutData(
List< VerticalLayoutData> verticalLayoutData) → List<HorizontalGroupData> -
Groups the VerticalLayoutData into horizontal groups.
inherited
-
hasChild(
Object childId) → bool -
True if a non-null LayoutChild was provided for the specified id.
inherited
-
layoutChild(
Object childId, BoxConstraints constraints) → Size -
Ask the child to update its layout within the limits specified by
the constraints parameter. The child's size is returned.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performLayout(
Size size) → void -
Override this method to lay out and position all children given this
widget's size.
override
-
positionChild(
Object childId, Offset offset) → void -
Specify the child's origin relative to this origin.
inherited
-
shouldRelayout(
covariant EventLayoutDelegate oldDelegate) → bool -
Override this method to return true when the children need to be
laid out.
inherited
-
sortEvents(
Iterable< KalenderEvent> events) → List<KalenderEvent> -
Sorts
eventsbefore layout.override -
sortVerticalLayoutData(
List< VerticalLayoutData> layoutData) → List<VerticalLayoutData> -
This is used to sort the vertical layout data after calculation.
override
-
toString(
) → String -
Override this method to include additional information in the
debugging data printed by debugDumpRenderTree and friends.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
arrange(
Iterable< VerticalLayoutData> verticalLayoutData) → List<SideBySidePlacement> -
Places
verticalLayoutDatain columns, so tiles that overlap never share horizontal space.