VerticalConfiguration class abstract Views

The base class for all vertical views of the calendar.

Implementers

Constructors

VerticalConfiguration({bool showMultiDayEvents = kDefaultShowMultiDayEvents, EdgeInsets horizontalPadding = kDefaultHorizontalPadding, EventLayoutStrategy eventLayoutStrategy = kDefaultEventLayoutStrategy, ScrollPhysics? scrollPhysics, ScrollPhysics? pageScrollPhysics, double? minimumTileHeight, PageTriggerConfiguration pageTriggerConfiguration = const PageTriggerConfiguration.defaultConfiguration(), ScrollTriggerConfiguration scrollTriggerConfiguration = const ScrollTriggerConfiguration.defaultConfiguration()})
const

Properties

eventLayoutStrategy EventLayoutStrategy
The layout strategy used by the body to layout events.
final
hashCode int
The hash code for this object.
no setteroverride
horizontalPadding EdgeInsets
The horizontal padding between events and the edge of the day column.
final
minimumTileHeight double?
The minimum height of the tile.
final
pageScrollPhysics ScrollPhysics?
The ScrollPhysics used by the page view.
final
pageTriggerConfiguration PageTriggerConfiguration
The configuration for the page navigation triggers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPhysics ScrollPhysics?
The ScrollPhysics used by the scrollable body.
final
scrollTriggerConfiguration ScrollTriggerConfiguration
The configuration for the scroll navigation triggers.
final
showMultiDayEvents bool
Whether to show multi-day events in the body.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override