horizontalPadding property
The horizontal padding between events and the edge of the day column.
- Vertical values are ignored.
Implementation
final EdgeInsets horizontalPadding;
The horizontal padding between events and the edge of the day column.
final EdgeInsets horizontalPadding;