snapshot method
What this view shows, for the view created on the next switch.
The base returns the start of floatingVisibleRange.
Implementation
ViewSnapshot snapshot() => ViewSnapshot(date: floatingVisibleRange.value.start);
What this view shows, for the view created on the next switch.
The base returns the start of floatingVisibleRange.
ViewSnapshot snapshot() => ViewSnapshot(date: floatingVisibleRange.value.start);