kalender_extensions library

Classes

InternalDateTime
A DateTime subclass that stores date/time components as-is via DateTime.utc, bypassing implicit timezone conversions.
InternalDateTimeRange
A DateTimeRange that uses InternalDateTime for timezone-safe display and layout.
Location
A Location maps time instants to the zone in use at that time. Typically, the Location represents the collection of time offsets in use in a geographical area, such as CEST and CET for central Europe.
TZDateTime
TimeZone aware DateTime.

Extensions

DateTimeExtensions on DateTime
Useful extensions for working with DateTime objects.
TimeOfDayExtension on TimeOfDay
Utility functions for working with TimeOfDay.