DayHeaderStyle class Appearance
The styling class for the DayHeader.
This class allows you to customize the appearance of the DayHeader widget. You can change the text style, the string displayed, the number text style, and the alignment.
- Mixed-in types
Constructors
- DayHeaderStyle({TextStyle? textStyle, TextStyle? numberTextStyle, MainAxisAlignment? mainAxisAlignment})
-
Use this function to customize the string used for the day number.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- mainAxisAlignment → MainAxisAlignment?
-
The main axis alignment of the DayHeader.
final
- numberTextStyle → TextStyle?
-
The TextStyle used by the DayHeader widget to display the day number of the week.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
The TextStyle used by the DayHeader widget to display the name of the day.
final
Methods
-
copyWith(
{TextStyle? textStyle, TextStyle? numberTextStyle, MainAxisAlignment? mainAxisAlignment}) → DayHeaderStyle - Creates a copy of this style with the given fields replaced with the new values.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
merge(
DayHeaderStyle? other) → DayHeaderStyle -
Returns a copy of this style where the non-null fields of
otherreplace the matching fields. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
DayHeaderStyle? a, DayHeaderStyle? b, double t) → DayHeaderStyle? -
Linearly interpolates between
aandb. Fields that cannot be interpolated switch at the midpoint.