EventLayoutDelegateCache class
A cache for EventLayoutDelegates.
This is used to cache some values that are recalculated often. What can/do we need to cache here ?
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → void -
getCache(
DateTime date, double heightPerMinute, TimeOfDayRange timeOfDayRange) → Map< int, VerticalLayoutData> ? -
Caches the vertical layout data for the given
date,heightPerMinute, andtimeOfDayRange. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCache(
DateTime date, double heightPerMinute, TimeOfDayRange timeRange, Map< int, VerticalLayoutData> cache) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited