HorizontalConfiguration class abstract
The base class for all horizontal views of the calendar.
- Implementers
Constructors
- HorizontalConfiguration({bool showTiles = defaultShowEventTiles, double tileHeight = defaultTileHeight, GenerateMultiDayLayoutFrame? generateMultiDayLayoutFrame, int? maximumNumberOfVerticalEvents, EdgeInsets eventPadding = kDefaultMultiDayEventPadding, required bool allowSingleDayEvents, PageTriggerConfiguration pageTriggerConfiguration = const PageTriggerConfiguration.defaultConfiguration()})
-
const
Properties
- allowSingleDayEvents → bool
-
Whether to display events shorter than 24 hours.
final
- eventPadding → EdgeInsets
-
The padding used around events.
final
- generateMultiDayLayoutFrame → GenerateMultiDayLayoutFrame?
-
The function that generates the layout frame for the multi-day event.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maximumNumberOfVerticalEvents → int?
-
The maximum number of events that can be displayed vertically.
final
- pageTriggerConfiguration → PageTriggerConfiguration
-
The configuration for the page navigation triggers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showTiles → bool
-
Whether to show event tiles.
final
- tileHeight → double
-
The height of the tiles.
final
Methods
-
copyWith(
{double? tileHeight, bool? showTiles, GenerateMultiDayLayoutFrame? generateMultiDayLayoutFrame, int? maximumNumberOfVerticalEvents, EdgeInsets? eventPadding, bool? allowSingleDayEvents, PageTriggerConfiguration? pageTriggerConfiguration}) → HorizontalConfiguration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override