maximumNumberOfVerticalEvents property
The maximum number of events that can be displayed vertically.
If this is null, then there is no limit.
Implementation
final int? maximumNumberOfVerticalEvents;
The maximum number of events that can be displayed vertically.
If this is null, then there is no limit.
final int? maximumNumberOfVerticalEvents;