HourLines class Appearance
A widget that displays lines for each hour based on the timeOfDayRange and heightPerMinute.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- HourLines
- Mixed-in types
Constructors
- HourLines({Key? key, required KalenderTimeRange timeOfDayRange, required double heightPerMinute, HourLinesStyle? style, TimelineStyle? timelineStyle})
-
Creates a new HourLines widget.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightPerMinute → double
-
The height per minute.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → HourLinesStyle?
-
The style of the hour lines.
final
- timelineStyle → TimelineStyle?
-
The style of the timeline.
final
- timeOfDayRange → KalenderTimeRange
-
The KalenderTimeRange that will be used to display the hour lines.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
effectiveStyle(
BuildContext context) → TimelineStyle -
The nearest KalenderTheme's timeline style overlaid with timelineStyle.
inherited
-
itemSize(
BuildContext context) → Size -
Calculates the Size of the item based on the textStyle and textPadding.
inherited
-
largestTextSize(
BuildContext context, TextStyle textStyle, EdgeInsets padding) → Size -
The Size of the largest text.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
segmentDuration(
KalenderTimeRange timeOfDayRange, double heightPerMinute, double itemHeight) → int -
Calculates the segments duration based on the
timeOfDayRange,heightPerMinute, anditemHeight.inherited -
textDirection(
BuildContext context) → TextDirection -
The TextDirection that will be used for the text.
inherited
-
textPadding(
BuildContext context) → EdgeInsets -
The EdgeInsets that will be used for the text.
inherited
-
textStyle(
BuildContext context) → TextStyle -
The TextStyle that will be used for the text.
inherited
-
timelineString(
BuildContext context, KalenderTime time) → String -
The label shown for
time.inherited -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited