MonthComponents class Appearance
A class containing custom widget builders for the MonthBody and MonthHeader.
Constructors
- MonthComponents({MonthBodyComponents bodyComponents = const MonthBodyComponents(), MonthHeaderComponents headerComponents = const MonthHeaderComponents()})
-
const
Properties
- bodyComponents → MonthBodyComponents
-
The component builders used by the MonthBody.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- headerComponents → MonthHeaderComponents
-
The component builders used by the MonthHeader.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{MonthBodyComponents? bodyComponents, MonthHeaderComponents? headerComponents}) → MonthComponents - Creates a copy of this with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override