MonthHeaderComponents class Appearance
The component builders used by the MonthHeader.
Constructors
- MonthHeaderComponents({WeekDayHeaderBuilder? weekDayHeaderBuilder, DateStringBuilder? weekDayHeaderStringBuilder})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weekDayHeaderBuilder → MonthDayHeaderBuilder?
-
A function that builds the week day header widget. Null uses WeekDayHeader.
final
- weekDayHeaderStringBuilder → DateStringBuilder?
-
Builds the day name displayed by the week day header.
final
Methods
-
buildWeekDayHeader(
BuildContext context, DateTime date) → Widget - Builds a week day header, with weekDayHeaderBuilder when set.
-
copyWith(
{WeekDayHeaderBuilder? weekDayHeaderBuilder, DateStringBuilder? weekDayHeaderStringBuilder}) → MonthHeaderComponents - Creates a copy of this with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override