MonthHeaderComponents class

The component builders used by the MonthHeader.

  • Using these will override the respective default components.

Constructors

MonthHeaderComponents({WeekDayHeaderBuilder weekDayHeaderBuilder = WeekDayHeader.builder})
Creates overrides for the default components used by the MonthHeader.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weekDayHeaderBuilder WeekDayHeaderBuilder
A function that builds the week day header widget.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited