MonthViewController class Controllers and callbacks
- Inheritance
-
- Object
- ViewController
- MonthViewController
Constructors
-
MonthViewController({required MonthViewConfiguration viewConfiguration, required ValueNotifier<
FloatingDateTimeRange?> floatingVisibleRange, required ValueNotifier<Set< visibleEvents, FloatingDateTime? initialDate, Location? location})KalenderEvent> >
Properties
- cache → EventLayoutDelegateCache
-
The cache used by the event layout delegate.
finalinherited
-
floatingVisibleRange
→ ValueNotifier<
FloatingDateTimeRange?> -
The range currently visible.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialPage ↔ int
-
The initial page of the view.
latefinal
- location ↔ Location?
-
The location of the current view.
getter/setter pairinherited
- multiDayCache → MultiDayLayoutFrameCache
-
The cache used for the multi-day event layout.
finalinherited
- numberOfPages ↔ int
-
The number of pages in the view.
latefinal
- pageController ↔ PageController
-
The page controller used by the view.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewConfiguration → MonthViewConfiguration
-
The view configuration that will be used by the controller.
final
-
visibleEvents
↔ ValueNotifier<
Set< KalenderEvent> > -
The KalenderEvents that are currently visible.
latefinaloverride-getter
Methods
-
animateToDate(
DateTime date, {Duration? duration, Curve? curve}) → Future< void> -
Animate to the date part of the given DateTime.
override
-
animateToDateTime(
DateTime date, {Duration? pageDuration, Curve? pageCurve, Duration? scrollDuration, Curve? scrollCurve}) → Future< void> -
Animate to the date and time parts of the given DateTime.
override
-
animateToEvent(
KalenderEvent event, {Duration? pageDuration, Curve? pageCurve, Duration? scrollDuration, Curve? scrollCurve, bool centerEvent = true}) → Future< void> -
Animate to the given KalenderEvent.
override
-
animateToNextPage(
{Duration? duration, Curve? curve}) → Future< void> -
Animate to the next page.
override
-
animateToPreviousPage(
{Duration? duration, Curve? curve}) → Future< void> -
Animate to the previous page.
override
-
dispose(
) → void -
override
-
jumpToDate(
DateTime date) → void -
Jump to the given DateTime.
override
-
jumpToPage(
int page) → void -
Jump to the given DateTime.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited