MultiDayBodyConfiguration class
The configuration used by the MultiDayBody.
TODO: Depricate this in 1.0.0 and use VerticalConfiguration instead.
- Inheritance
-
- Object
- VerticalConfiguration
- MultiDayBodyConfiguration
Constructors
- MultiDayBodyConfiguration({bool showMultiDayEvents = defaultShowMultiDayEvents, EdgeInsets horizontalPadding = defaultHorizontalPadding, EventLayoutStrategy eventLayoutStrategy = defaultEventLayoutStrategy, ScrollPhysics? scrollPhysics, ScrollPhysics? pageScrollPhysics, double? minimumTileHeight, PageTriggerConfiguration pageTriggerConfiguration = const PageTriggerConfiguration.defaultConfiguration(), ScrollTriggerConfiguration scrollTriggerConfiguration = const ScrollTriggerConfiguration.defaultConfiguration()})
-
Creates a new MultiDayHeaderConfiguration.
const
Properties
- eventLayoutStrategy → EventLayoutStrategy
-
The layout strategy used by the body to layout events.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalPadding → EdgeInsets
-
The horizontal padding between events and the edge of the day column.
finalinherited
- minimumTileHeight → double?
-
The minimum height of the tile.
finalinherited
- pageScrollPhysics → ScrollPhysics?
-
The ScrollPhysics used by the page view.
finalinherited
- pageTriggerConfiguration → PageTriggerConfiguration
-
The configuration for the page navigation triggers.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollPhysics → ScrollPhysics?
-
The ScrollPhysics used by the scrollable body.
finalinherited
- scrollTriggerConfiguration → ScrollTriggerConfiguration
-
The configuration for the scroll navigation triggers.
finalinherited
- showMultiDayEvents → bool
-
Whether to show events that are longer than 1 day.
finalinherited
Methods
-
copyWith(
{bool? showMultiDayEvents, EdgeInsets? horizontalPadding, PageTriggerConfiguration? pageTriggerConfiguration, ScrollTriggerConfiguration? scrollTriggerConfiguration, EventLayoutStrategy? eventLayoutStrategy, ScrollPhysics? scrollPhysics, ScrollPhysics? pageScrollPhysics, double? minimumTileHeight}) → MultiDayBodyConfiguration - Creates a copy of this MultiDayBodyConfiguration with the given fields replaced by the new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited