MultiDayViewConfiguration class
The configuration used by the MultiDayBody and MultiDayHeader.
- Inheritance
-
- Object
- ViewConfiguration
- MultiDayViewConfiguration
Constructors
- MultiDayViewConfiguration({required String name, DateTime? initialDateTime, InitialDateSelectionStrategy initialDateSelectionStrategy = kDefaultInitialDateSelectionStrategy, NowCallback? nowCallback, required TimeOfDayRange timeOfDayRange, required int numberOfDays, required int firstDayOfWeek, required PageIndexCalculator pageIndexCalculator, required MultiDayViewType type, required TimeOfDay initialTimeOfDay, required double initialHeightPerMinute})
-
MultiDayViewConfiguration.custom({String name = 'Custom', DateTime? initialDateTime, InitialDateSelectionStrategy initialDateSelectionStrategy = kDefaultToWeekly, NowCallback? nowCallback, DateTimeRange<
DateTime> ? displayRange, TimeOfDayRange? timeOfDayRange, required int numberOfDays, int firstDayOfWeek = defaultFirstDayOfWeek, TimeOfDay initialTimeOfDay = defaultInitialTimeOfDay, double initialHeightPerMinute = defaultHeightPerMinute}) - Creates a MultiDayViewConfiguration for a custom number of days.
-
MultiDayViewConfiguration.freeScroll({String name = 'Free Scroll', DateTime? initialDateTime, InitialDateSelectionStrategy initialDateSelectionStrategy = kDefaultToWeekly, NowCallback? nowCallback, DateTimeRange<
DateTime> ? displayRange, TimeOfDayRange? timeOfDayRange, required int numberOfDays, TimeOfDay initialTimeOfDay = defaultInitialTimeOfDay, double initialHeightPerMinute = defaultHeightPerMinute}) - Creates a MultiDayViewConfiguration for a free scrolling view.
-
MultiDayViewConfiguration.singleDay({String name = 'Day', DateTime? initialDateTime, InitialDateSelectionStrategy initialDateSelectionStrategy = kDefaultToDaily, NowCallback? nowCallback, DateTimeRange<
DateTime> ? displayRange, TimeOfDayRange? timeOfDayRange, int firstDayOfWeek = defaultFirstDayOfWeek, TimeOfDay initialTimeOfDay = defaultInitialTimeOfDay, double initialHeightPerMinute = defaultHeightPerMinute}) - Creates a MultiDayViewConfiguration for a single day.
-
MultiDayViewConfiguration.week({String name = 'Week', DateTime? initialDateTime, InitialDateSelectionStrategy initialDateSelectionStrategy = kDefaultToWeekly, NowCallback? nowCallback, DateTimeRange<
DateTime> ? displayRange, TimeOfDayRange? timeOfDayRange, int firstDayOfWeek = defaultFirstDayOfWeek, int numberOfDays = 7, TimeOfDay initialTimeOfDay = defaultInitialTimeOfDay, double initialHeightPerMinute = defaultHeightPerMinute}) - Creates a MultiDayViewConfiguration for a week.
-
MultiDayViewConfiguration.workWeek({String name = 'Work Week', DateTime? initialDateTime, InitialDateSelectionStrategy initialDateSelectionStrategy = kDefaultToWeekly, NowCallback? nowCallback, DateTimeRange<
DateTime> ? displayRange, TimeOfDayRange? timeOfDayRange, int numberOfDays = 5, TimeOfDay initialTimeOfDay = defaultInitialTimeOfDay, double initialHeightPerMinute = defaultHeightPerMinute}) - Creates a MultiDayViewConfiguration for a work week.
Properties
-
dateTimeRange
→ DateTimeRange<
DateTime> -
The DateTimeRange that the calendar can display.
no setterinherited
- firstDayOfWeek → int
-
The first day of the week.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- initialDateSelectionStrategy → InitialDateSelectionStrategy
-
The strategy used for determining initial date when transitioning between view configurations.
finalinherited
- initialDateTime → DateTime?
-
The selected date to start the view from.
finalinherited
- initialHeightPerMinute → double
-
The initial heightPerMinute (zoom level).
final
- initialTimeOfDay → TimeOfDay
-
The initial time of day that the calendar should display.
final
- name → String
-
The name of the ViewConfiguration.
finalinherited
- nowCallback → NowCallback?
-
An optional callback that overrides how the calendar resolves "now".
finalinherited
- numberOfDays → int
-
The number of days that can be displayed by MultiDayBody widgets using this configuration.
final
- pageIndexCalculator → PageIndexCalculator
-
The functions for navigating the PageView.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeOfDayRange → TimeOfDayRange
-
The TimeOfDayRange that can be displayed by MultiDayBody widgets using this configuration.
final
- type → MultiDayViewType
-
The type of the MultiDayViewConfiguration.
final
Methods
-
copyWith(
{String? name, DateTime? initialDateTime, InitialDateSelectionStrategy? initialDateSelectionStrategy, NowCallback? nowCallback, TimeOfDayRange? timeOfDayRange, DateTimeRange< DateTime> ? displayRange, int? numberOfDays, int? firstDayOfWeek, TimeOfDay? initialTimeOfDay}) → MultiDayViewConfiguration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override