ResizeHandleDetails class Interaction
What a ResizeHandlePositioner needs to lay out the resize handles of one event tile.
Constructors
- ResizeHandleDetails({required KalenderEvent event, required KalenderInteraction interaction, required FloatingDateTimeRange range, required Size size, required Axis axis, required bool isImprecise})
-
const
Properties
- axis → Axis
-
The axis along which the resize handles are positioned.
final
- endResizeDetector → ResizeDetector
-
The end resize detector.
no setter
- event → KalenderEvent
-
The event associated with the resize handles.
final
- eventInteraction → EventInteraction
-
The interaction settings for this event.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- interaction → KalenderInteraction
-
The global interaction settings for the calendar.
final
- isImprecise → bool
-
Whether the current input is imprecise (e.g. touch/finger).
final
- isVertical → bool
-
Whether the axis is vertical.
no setter
- range → FloatingDateTimeRange
-
The FloatingDateTimeRange that the current view is displaying.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
The size of the event tile.
final
- startResizeDetector → ResizeDetector
-
The start resize detector.
no setter
Methods
-
continuesAfter(
{Location? location}) → bool - Whether the event continues after the current date range.
-
continuesBefore(
{Location? location}) → bool - Whether the event continues before the current date range.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resizeHandle(
BuildContext context, {Axis? axis}) → Widget -
The resize handle to use, resolved from the TileComponents of
context. -
showEnd(
{Location? location}) → bool - Whether to show the end resize handle, based on interaction settings and event continuation.
-
showStart(
{Location? location}) → bool - Whether to show the start resize handle, based on interaction settings and event continuation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited