ScrollTransition enum Views
How the vertical scroll position (time-of-day) is chosen when switching to a multi-day view.
Values
- preserve → const ScrollTransition
-
Keep the time-of-day the user was last looking at in a multi-day view (survives a round-trip through a view without scroll, e.g. Month). Default.
- reset → const ScrollTransition
-
Reset to the view's configured
initialTimeOfDay. - restorePerView → const ScrollTransition
-
Restore the time-of-day this view last displayed (matched by configuration
name), falling back to preserve.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ScrollTransition> - A constant List of the values in this enum, in order of their declaration.