TileBuilder typedef Appearance
TileBuilder =
Widget Function(BuildContext context, KalenderEvent event, KalenderDateTimeRange tileRange)
The default builder for the event tiles.
event is the event that the tile will be built for.
tileRange is the wall-clock KalenderDateTimeRange of the view the tile will be displayed in.
The values are local DateTimes (or TZDateTimes when a timezone location is set).
Implementation
typedef TileBuilder = Widget Function(BuildContext context, KalenderEvent event, KalenderDateTimeRange tileRange);