TimelineStyle class Appearance
The style of the TimeLine widget.
- Mixed-in types
Constructors
- TimelineStyle({TextStyle? textStyle, TextDirection? textDirection, TextAlign? textAlign, TextOverflow? textOverflow, EdgeInsets? textPadding, double? width, Decoration? startDecoration, Decoration? endDecoration})
-
const
Properties
- endDecoration → Decoration?
-
The decoration for the event end time.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDecoration → Decoration?
-
The function that will be used to build the string.
The decoration for the event start time.
final
- textAlign → TextAlign?
-
The text align of the text.
final
- textDirection → TextDirection?
-
The text direction of the text.
final
- textOverflow → TextOverflow?
-
The text overflow of the text.
final
- textPadding → EdgeInsets?
-
The padding of the text.
final
- textStyle → TextStyle?
-
The style of the text.
final
- width → double?
-
An explicit width for the timeline gutter.
final
Methods
-
copyWith(
{TextStyle? textStyle, TextDirection? textDirection, TextAlign? textAlign, TextOverflow? textOverflow, EdgeInsets? textPadding, double? width, Decoration? startDecoration, Decoration? endDecoration}) → TimelineStyle - Creates a copy of this style with the given fields replaced with the new values.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
merge(
TimelineStyle? other) → TimelineStyle -
Returns a copy of this style where the non-null fields of
otherreplace the matching fields. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
TimelineStyle? a, TimelineStyle? b, double t) → TimelineStyle? -
Linearly interpolates between
aandb. Fields that cannot be interpolated switch at the midpoint.