VerticalLayoutData class Layout
This stores the vertical layout data of a single KalenderEvent.
Constructors
- VerticalLayoutData({required int id, required double top, required double bottom})
Properties
- bottom → double
-
The bottom of the event.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the event.
no setter
- id → int
-
The id of the event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → double
-
The top of the event.
final
Methods
-
copyWith(
{int? id}) → VerticalLayoutData -
Creates a copy of this VerticalLayoutData with a new
id. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overlaps(
VerticalLayoutData other) → bool -
Checks if this VerticalLayoutData overlaps with
other. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited