dateTimeRange property
DateTimeRange<DateTime>
get
dateTimeRange
The DateTimeRange that the calendar can display.
This might be different depending on the location of the calendar view.
to get the exact range for a location, use: PageIndexCalculator.displayRangeForLocation
Implementation
DateTimeRange get dateTimeRange => pageIndexCalculator.dateTimeRange;