dateTransition property
How the visible date is chosen when switching to this view from another, or when the calendar's location changes.
Defaults to DateTransition.carryFocus. Overridden by dateResolver when that is provided.
Implementation
final DateTransition dateTransition;