ViewController class abstract
A controller for calendar views.
A view controller lets you control a calendar view.
Constructors
-
ViewController({Location? location, required ValueNotifier<
InternalDateTimeRange?> visibleDateTimeRange})
Properties
- cache → EventLayoutDelegateCache
-
TODO: this can be passed between ViewControllers, but for now it is created here.
The cache used by the event layout delegate.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location ↔ Location?
-
The location of the current view.
getter/setter pair
- multiDayCache → MultiDayLayoutFrameCache
-
The cache used for the multi-day event layout.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewConfiguration → ViewConfiguration
-
The view configuration that will be used by the controller.
no setter
-
visibleDateTimeRange
→ ValueNotifier<
InternalDateTimeRange?> -
The InternalDateTimeRange that is currently visible.
final
-
visibleEvents
→ ValueNotifier<
Set< CalendarEvent> > -
The CalendarEvents that are currently visible.
no setter
Methods
-
animateToDate(
DateTime date, {Duration? duration, Curve? curve}) → Future< void> - Animate to the date part of the given DateTime.
-
animateToDateTime(
DateTime date, {Duration? pageDuration, Curve? pageCurve, Duration? scrollDuration, Curve? scrollCurve}) → Future< void> - Animate to the date and time parts of the given DateTime.
-
animateToEvent(
CalendarEvent event, {Duration? pageDuration, Curve? pageCurve, Duration? scrollDuration, Curve? scrollCurve, bool centerEvent = true}) → Future< void> - Animate to the given CalendarEvent.
-
animateToNextPage(
{Duration? duration, Curve? curve}) → Future< void> - Animate to the next page.
-
animateToPreviousPage(
{Duration? duration, Curve? curve}) → Future< void> - Animate to the previous page.
-
dispose(
) → void -
jumpToDate(
DateTime date) → FutureOr< void> - Jump to the given DateTime.
-
jumpToPage(
int page) → void - Jump to the given DateTime.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited