WeekDayHeaderStyle class Appearance
The WeekDayHeaderStyle class is used by the default WeekDayHeader widget.
- Mixed-in types
Constructors
- WeekDayHeaderStyle({TextStyle? textStyle, EdgeInsets? padding})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- padding → EdgeInsets?
-
The padding around the WeekDayHeader widget.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
The TextStyle used to display the day of the week.
final
Methods
-
copyWith(
{TextStyle? textStyle, EdgeInsets? padding}) → WeekDayHeaderStyle - Creates a copy of this style with the given fields replaced with the new values.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
merge(
WeekDayHeaderStyle? other) → WeekDayHeaderStyle -
Returns a copy of this style where the non-null fields of
otherreplace the matching fields. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
WeekDayHeaderStyle? a, WeekDayHeaderStyle? b, double t) → WeekDayHeaderStyle? -
Linearly interpolates between
aandb. Fields that cannot be interpolated switch at the midpoint.