WeekDayHeaderStyle class

The WeekDayHeaderStyle class is used by the default WeekDayHeader widget.

Constructors

WeekDayHeaderStyle({TextStyle? textStyle, EdgeInsets? padding, String stringBuilder(DateTime date)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets?
The padding around the WeekDayHeader widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringBuilder String Function(DateTime date)?
Use this function to customize the sting displayed by the WeekDayHeader.
final
textStyle TextStyle?
The TextStyle used by the DateText widget to display the day of the week.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited