kalender_extensions library

Classes

InternalDateTime
A timezone-agnostic DateTime subclass used internally for display and layout purposes.
InternalDateTimeRange
This is a DateTimeRange class used for internal display purposes only.
Location
A Location maps time instants to the zone in use at that time. Typically, the Location represents the collection of time offsets in use in a geographical area, such as CEST and CET for central Europe.
LocationDatabase
LocationDatabase provides interface to find Locations by their name.
TimeZone
A TimeZone represents a single time zone such as CEST or CET.
TZDateTime
TimeZone aware DateTime.
TzInstant
A TzInstant represents a timezone and an instant in time.

Extensions

DateTimeExtensions on DateTime
Useful extensions for working with DateTime objects.
TimeOfDayExtension on TimeOfDay
Utility functions for working with TimeOfDay.

Constants

maxTime → const int
Maximum value for time instants.
minTime → const int
Minimum value for time instants.
tzDataDefaultFilename → const String
File name of the Time Zone default database.

Properties

local Location
Local Location
no setter
timeZoneDatabase LocationDatabase
Global TimeZone database
no setter
UTC Location
UTC Location
no setter

Functions

getLocation(String locationName) Location
Find Location by its name.
initializeDatabase(List<int> rawData) → void
Initialize Time zone database.
setLocalLocation(Location location) → void
Set local Location