kalender_extensions
library
Classes
-
InternalDateTime
-
A timezone-agnostic DateTime subclass used internally for display and layout purposes.
-
InternalDateTimeRange
-
This is a DateTimeRange class used for internal display purposes only.
-
Location
-
A Location maps time instants to the zone in use at that time.
Typically, the Location represents the collection of time offsets
in use in a geographical area, such as CEST and CET for central Europe.
-
LocationDatabase
-
LocationDatabase provides interface to find Locations by their name.
-
TimeZone
-
A TimeZone represents a single time zone such as CEST or CET.
-
TZDateTime
-
TimeZone aware DateTime.
-
TzInstant
-
A TzInstant represents a timezone and an instant in time.